@@ -5,23 +5,24 @@
 #'
 #' @param x genind object (from package adegenet)
 #' @export
-#' @examples
-#' 
-#' data(nancycats)
-#' Gst_Nei(nancycats)
 #' @references
 #'  Nei M. (1973) Analysis of gene diversity in subdivided populations. PNAS: 3321-3323. 
 #' @references
 #'  Nei M, Chesser RK. (1983). Estimation of fixation indices and gene diversities. Annals of Human Genetics. 47: 253-259.
 #' @family diffstat
 #' @family Nei
+#' @examples
+#' 
+#' data(nancycats)
+#' Gst_Nei(nancycats)
 
 Gst_Nei <- function(x){
   n <- length(unique(pop(x)))
   harmN <- harmonic_mean(table(pop(x)))
+  pops <- pop(x)
   Gst.per.locus <- function(g) {
-    #what we need to calculate these stats
-    a <- makefreq(genind2genpop(g, quiet=T), quiet=T)[[1]]
+    #what we need to calculate these 
+    a <- apply(g@tab,2,function(row) tapply(row, pops, mean, na.rm=TRUE))
     HpS <- sum(1 - apply(a^2, 1, sum, na.rm=TRUE)) / n
     Hs_est <- (2*harmN/(2*harmN-1))*HpS
     HpT <- 1 - sum(apply(a,2,mean, na.rm=TRUE)^2)
