@@ -6,8 +6,6 @@
 #'
 #' @param x genind object (from package adegenet)
 #' @param linearized logical, if TRUE will turned linearized D (1/1-D)
-#' @param global.het logical if TRUE returns global estimate of D based on 
-#' mean heterozysoity (FALSE for harmonic mean)
 #' @export
 #' @examples
 #' 
@@ -18,7 +16,7 @@
 #' @family pairwise
 #' @family D
 
-pairwise_D <- function(x, linearized=FALSE, global.het=TRUE) {
+pairwise_D <- function(x, linearized=FALSE) {
   pops <- seppop(x)
   n.pops <- length(pops)
   #all combinations 
@@ -28,19 +26,14 @@ pairwise_D <- function(x, linearized=FALSE, global.het=TRUE) {
     a <- pops[[index.a]]
     b <- pops[[index.b]]
     temp <- repool(a,b)
-    if(global.het){
-      return(D_Jost(temp)$global.het)
-      }
-    else
-      return(D_Jost(temp)$global.harm_mean)
-  }
+    return(D_Jost(temp)$global.het)
+    }
   res <- sapply(1:dim(allP)[2], function(i) pair(allP[,i][1], allP[,i][2]))
   attributes(res) <- attributes(dist(1:n.pops))
   if(linearized){
      return(res/(1-res))
      }
-  else
-    return(res)
+  else(return(res))
 }
 
 
